@@ -1,7 +1,7 @@
 ;;; viper-ex.el --- functions implementing the Ex commands for Viper
 
 ;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 2000, 2001, 2002, 2003,
-;;   2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+;;   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 
@@ -47,12 +47,8 @@
 (if noninteractive
     (eval-when-compile
       (let ((load-path (cons (expand-file-name ".") load-path)))
-	(or (featurep 'viper-util)
-	    (load "viper-util.el" nil nil 'nosuffix))
-	(or (featurep 'viper-keym)
-	    (load "viper-keym.el" nil nil 'nosuffix))
 	(or (featurep 'viper-cmd)
-	    (load "viper-cmd.el" nil nil 'nosuffix))
+	    (load "viper-cmd.el" nil t 'nosuffix))
 	)))
 ;; end pacifier
 
@@ -1103,7 +1099,7 @@ reversed."
 	 beg end cont val)
 
     (viper-add-keymap ex-read-filename-map
-		    (if viper-emacs-p
+		    (if (featurep 'emacs)
 			minibuffer-local-completion-map
 		      read-file-name-map))
 
@@ -1558,7 +1554,7 @@ reversed."
       ;; setup buffer
       (if (setq wind (viper-get-visible-buffer-window buf))
 	  ()
-	(setq wind (get-lru-window (if viper-xemacs-p nil 'visible)))
+	(setq wind (get-lru-window (if (featurep 'xemacs) nil 'visible)))
 	(set-window-buffer wind buf))
 
       (if (viper-window-display-p)
@@ -1878,7 +1874,7 @@ reversed."
   (condition-case nil
       (progn
 	(pop-to-buffer (get-buffer-create "*info*"))
-	(info (if viper-xemacs-p "viper.info" "viper"))
+	(info (if (featurep 'xemacs) "viper.info" "viper"))
 	(message "Type `i' to search for a specific topic"))
     (error (beep 1)
 	   (with-output-to-temp-buffer " *viper-info*"
@@ -1887,7 +1883,7 @@ The Info file for Viper does not seem to be installed.
 
 This file is part of the standard distribution of %sEmacs.
 Please contact your system administrator. "
-			    (if viper-xemacs-p "X" "")
+			    (if (featurep 'xemacs) "X" "")
 			    ))))))
 
 ;; Ex source command.  Loads the file specified as argument or `~/.viper'
@@ -2220,9 +2216,11 @@ Type 'mak ' (including the space) to run make with no args."
 	(pos2 (viper-line-pos 'end))
 	lines file info)
     (setq lines (count-lines (point-min) (viper-line-pos 'end))
-	  file (if (buffer-file-name)
-		   (concat (viper-abbreviate-file-name (buffer-file-name)) ":")
-		 (concat (buffer-name) " [Not visiting any file]:"))
+	  file (cond ((buffer-file-name)
+		      (concat (viper-abbreviate-file-name (buffer-file-name)) ":"))
+		     ((buffer-file-name (buffer-base-buffer))
+		      (concat (viper-abbreviate-file-name (buffer-file-name (buffer-base-buffer))) " (indirect buffer):"))
+		     (t (concat (buffer-name) " [Not visiting any file]:")))
 	  info (format "line=%d/%d pos=%d/%d col=%d %s"
 		       (if (= pos1 pos2)
 			   (1+ lines)
