@@ -1,7 +1,7 @@
 ;;; viper-keym.el --- Viper keymaps
 
 ;; Copyright (C) 1994, 1995, 1996, 1997, 2000, 2001, 2002, 2003, 2004,
-;;   2005, 2006, 2007 Free Software Foundation, Inc.
+;;   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 
@@ -26,8 +26,6 @@
 
 ;;; Code:
 
-(provide 'viper-keym)
-
 ;; compiler pacifier
 (defvar viper-always)
 (defvar viper-current-state)
@@ -35,19 +33,14 @@
 (defvar viper-expert-level)
 (defvar viper-ex-style-editing)
 (defvar viper-ex-style-motion)
-
-;; loading happens only in non-interactive compilation
-;; in order to spare non-viperized emacs from being viperized
-(if noninteractive
-    (eval-when-compile
-      (let ((load-path (cons (expand-file-name ".") load-path)))
-	(or (featurep 'viper-util)
-	    (load "viper-util.el" nil nil 'nosuffix))
-	)))
 ;; end pacifier
 
 (require 'viper-util)
 
+;; declare-function is not defined in XEmacs
+;;(declare-function viper-ex "viper-ex" (arg &optional string))
+;;(declare-function viper-normalize-minor-mode-map-alist "viper-cmd" ())
+;;(declare-function viper-set-mode-vars-for "viper-cmd" (state))
 
 ;;; Variables
 
@@ -702,6 +695,9 @@ form ((key . function) (key . function) ... )."
 	   alist))
 
 
+(provide 'viper-keym)
+
+
 ;;; Local Variables:
 ;;; eval: (put 'viper-deflocalvar 'lisp-indent-hook 'defun)
 ;;; End:
